@@ -107,13 +107,14 @@ class Storage(driver.Base):
         path1 = self._init_path(path)
         
         try:
-            files = self._jss.bucket(self._bucket).get_all_keys(headers=None, prefix=path1)
-            logger.info("list_directory files:%s" % files)
-            if len(list(files)) == 0 :
+            response = self._jss.bucket(self._bucket).get_all_keys(headers=None, prefix=path1)
+            logger.info("list_directory files:%s" % response)
+            files = response["Contents"] 
+            if len(files) == 0 :
                 raise Exception('empty')
             
             for file in files:
-                yield file
+                yield file["Key"]
         except Exception as e:
             logger.error("list_directory error:%s" % e)
             raise exceptions.FileNotFoundError("File not found %s" % path)
